@@ -43,7 +43,7 @@ use 5.008;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.1002';
+our $VERSION = '0.1003';
 
 use Moose;
 
@@ -593,11 +593,11 @@ The API is not stable yet and can be changed in future.
 
 =head1 AUTHOR
 
-Piotr Roszatycki <dexter@debian.org>
+Piotr Roszatycki <dexter@cpan.org>
 
 =head1 LICENSE
 
-Copyright 2008, 2009 by Piotr Roszatycki E<lt>dexter@debian.orgE<gt>.
+Copyright 2008, 2009 by Piotr Roszatycki <dexter@cpan.org>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
